/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DatabaseImpl.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.client.xmldb.managed;

import org.apache.xindice.client.xmldb.CommonConfigurable;

/**
 * The xindice-managed is a xindice client driver that requires third party code
 * to create the database within the constraints of the client classloader. Typically
 * it is used in embedded environments where database creation is managed by the third
 * party code.
 *
 * This driver will throw an exception if the database instance you are trying to access
 * hasn't been registered.
 *
 * @author <a href="mailto:kevin@rocketred.com.au">Kevin O'Neill</a>
 * @author <a href="mailto:vgritsenko@apache.org">Vadim Gritsenko</a>
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class DatabaseImpl extends org.apache.xindice.client.xmldb.embed.DatabaseImpl {

    /**
     * Prefix used to denote XML:DB URI's that should use this driver
     */
    public static final String DRIVER_NAME = "xindice-managed";


    /**
     * Creates new <code>DatabaseImpl</code> instance.
     */
    public DatabaseImpl() {
        super();
    }

    /**
     * Create a new DatabaseImpl object with a copy of the properties
     * from the <code>config</code> parameter.
     *
     * This allows to pass properties such as PROP_XINDICE_CONFIGURATION
     * to this instance. Usually this is done by instantiating not this
     * class, but {@link org.apache.xindice.client.xmldb.DatabaseImpl},
     * set all the necessary parameters, and then get a collection.
     *
     * @param config from which the initial parameters for this
     *        DatabaseImpl object are copied.
     */
    public DatabaseImpl(CommonConfigurable config) {
        super(config);
    }

    /**
     * @return true
     */
    protected boolean isManaged() {
        return true;
    }

    public boolean acceptsURI(String uri) {
        return ((uri != null) && uri.startsWith(getName() + "://"));
    }

    /* (non-Javadoc)
     * @see org.xmldb.api.base.Database#getName()
     */
    public String getName() {
        return DRIVER_NAME;
    }

    /* (non-Javadoc)
     * @see org.xmldb.api.base.Database#getNames()
     */
    public String[] getNames() {
        return new String[]{ DRIVER_NAME };
    }
}
