/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: BinaryResourceImpl.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.client.xmldb.resources;

import org.xmldb.api.base.Collection;
import org.xmldb.api.base.XMLDBException;
import org.xmldb.api.modules.BinaryResource;

/**
 * BinaryResourceImpl provides an implementation to handle XML:DB binary
 * resource.
 *
 * As per XML:DB spec, binary resource supports only byte[] data.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class BinaryResourceImpl implements BinaryResource {

    private String id;
    private byte[] content;
    private Collection collection;


    public BinaryResourceImpl(String id, byte[] content) {
        this(id, null, content);
    }

    public BinaryResourceImpl(String id, Collection collection, byte[] content) {
        this.id = id;
        this.content = content;
        this.collection = collection;
    }

    /**
     * @see org.xmldb.api.base.Resource#getContent()
     */
    public Object getContent() throws XMLDBException {
        return this.content;
    }

    /**
     * @see org.xmldb.api.base.Resource#getId()
     */
    public String getId() throws XMLDBException {
        return this.id;
    }

    /**
     * @see org.xmldb.api.base.Resource#getParentCollection()
     */
    public Collection getParentCollection() throws XMLDBException {
        return this.collection;
    }

    /**
     * @see org.xmldb.api.base.Resource#getResourceType()
     */
    public String getResourceType() throws XMLDBException {
        return "BinaryResource";
    }

    /**
     * @see org.xmldb.api.base.Resource#setContent(Object)
     */
    public void setContent(Object content) throws XMLDBException {
        this.content = (byte[])content;
    }

    public void setId(String id) {
        this.id = id;
    }
}
