/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: XUpdateQueryServiceImpl.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.client.xmldb.services;

import org.w3c.dom.Document;
import org.xmldb.api.base.ErrorCodes;
import org.xmldb.api.base.XMLDBException;
import org.xmldb.api.modules.XMLResource;
import org.xmldb.api.modules.XUpdateQueryService;

/**
 * XML:DB XUpdateQueryService implementation that uses XML-RPC communication
 * with server
 *
 * @author <a href="mailto:james.bates@amplexor.com">James Bates</a>
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class XUpdateQueryServiceImpl extends QueryService implements XUpdateQueryService {

    /**
     * Creates new XUpdateQueryService
     */
    public XUpdateQueryServiceImpl() {

        super();
        queryLang = "XUpdate";
    }

    /**
     * Extracts modified count from the pseudo-result returned from query
     */
    private long getResultCount(XMLResource resource) throws XMLDBException {

        Document doc = (Document) resource.getContentAsDOM();

        /**
         * Modified by tlr - server sends:
         * <src:modified xmlns:src="http://xml.apache.org/xindice/Query">1</src:modified>
         * which is not properly decoded by original code (drills one level too deep)
         // Get the src:modified element
         Node node = doc.getDocumentElement().getFirstChild();

         // The count is a text node within the element.
         String count = node.getFirstChild().getNodeValue();
         **/
        String count = null;
        try {
            count = doc.getDocumentElement().getFirstChild().getNodeValue();
        } catch (Exception e) {
            throw new XMLDBException(ErrorCodes.VENDOR_ERROR, "Unable to retrieve <src:modified> element content from server result", e);
        }

        try {
            return Long.parseLong(count);
        } catch (Exception e) {
            throw new XMLDBException(ErrorCodes.VENDOR_ERROR, "<src:modified> in server result did not contain a valid count", e);
        }
    }

    /**
     * Performs an XUpdate operation on the entire collection
     */
    public long update(String query) throws XMLDBException {

        return getResultCount((XMLResource) query(query).getResource(0));
    }

    /**
     * Preforms an XUpdate operation on the specified document
     */
    public long updateResource(String name, String query) throws XMLDBException {

        return getResultCount((XMLResource) queryResource(name, query).getResource(0));
    }
}
