/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DBException.java 564998 2007-08-12 02:51:49Z vgritsenko $
 */

package org.apache.xindice.core;

import org.apache.xindice.util.XindiceException;

/**
 * A DBException is thrown by the database if an exception occurs in the
 * managing (creating, dropping) database objects such as Collections,
 * Indexes, and XMLObjects.
 *
 * @version $Revision: 564998 $, $Date: 2007-08-11 22:51:49 -0400 (Sat, 11 Aug 2007) $
 */
public class DBException extends XindiceException {
    public final int faultCode;

    public DBException() {
        this(FaultCodes.GEN_UNKNOWN, "", null);
    }

    public DBException(int faultCode) {
        this(faultCode, "", null);
    }

    public DBException(int faultCode, String message) {
        this(faultCode, message, null);
    }

    public DBException(int faultCode, String message, Throwable cause) {
        super(message, cause);
        this.faultCode = faultCode;
    }
}
