/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DocumentSet.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.core.data;

import org.apache.xindice.core.Container;
import org.apache.xindice.core.DBException;

import org.w3c.dom.Document;

/**
 * DocumentSet is an interface for iterating over a set of Documents.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface DocumentSet {

    /**
     * hasMoreDocuments returns whether there are any more Documents
     * left in the set.
     *
     * @return Whether there are more Documents
     */
    boolean hasMoreDocuments() throws DBException;

    /**
     * getNextDocument returns the next Document in the set.
     *
     * @return The next Document
     */
    Document getNextDocument() throws DBException;

    /**
     * getNextContainer returns the next Document in the set wrapped
     * in a Collection Container.  Containers store extra information
     * about the Document (like its Key)
     *
     * @return The next Container
     */
    Container getNextContainer() throws DBException;
}
