/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Record.java 571953 2007-09-02 11:04:38Z vgritsenko $
 */

package org.apache.xindice.core.data;

import java.util.Collections;
import java.util.Map;

/**
 * Record is a container for key/value pairs and all meta data stored
 * with this record in the database.
 *
 * @version $Revision: 571953 $, $Date: 2007-09-02 07:04:38 -0400 (Sun, 02 Sep 2007) $
 */
public final class Record {
    public static final String CREATED  = "created";
    public static final String MODIFIED = "modified";

    public static final String OWNER = "owner";
    public static final String GROUP = "group";

    private final Key key;
    private final Value value;
    private final Map meta;


    public Record(Key key, Value value) {
        this.key = key;
        this.value = value;
        this.meta = Collections.EMPTY_MAP;
    }

    public Record(Key key, Value value, Map meta) {
        this.key = key;
        this.value = value;
        this.meta = meta;
    }

    /**
     * getKey returns the Record's Key.
     *
     * @return The Record's Key
     */
    public Key getKey() {
        return key;
    }

    /**
     * getValue returns the Record's Value.
     *
     * @return The Record's Value
     */
    public Value getValue() {
        return value;
    }

    /**
     * getMetaData returns metadata about the Value.
     *
     * @param name The property name
     * @return The metadata value
     */
    public Object getMetaData(Object name) {
        return meta.get(name);
    }
}
