/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: TimeRecord.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.core.meta;

import java.util.Date;

/**
 * Encapsulates the modified/create times used in MetaData.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class TimeRecord {

    long created = 0;
    long modified = 0;


    public TimeRecord(long created, long modified) {
        this.created = created;
        this.modified = modified;
    }

    /**
     * Returns the create time stored here.
     *
     * @return long
     */
    public long getCreatedTime() {
        return created;
    }

    /**
     * Returns the modified time stored here.
     *
     * @return long
     */
    public long getModifiedTime() {
        return modified;
    }

    /**
     * Sets the create time stored here.
     *
     * @param created The new create time
     */
    public void setCreatedTime(long created) {
        this.created = created;
    }

    /**
     * Sets the modified time stored here.
     *
     * @param mod The new modified time
     */
    public void setModifiedTime(long mod) {
        this.modified = mod;
    }

    /**
     * Return a string version of the times encapsulated. It should look like
     *   [cr=CREATE mod=MOD]
     *
     * @return The string representing the time
     */
    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("[");
        if (created > 0) {
            buffer.append("cr=" + (new Date(created)).toString());
        }
        if (modified > 0) {
            buffer.append("mod=" + (new Date(modified)).toString());
        }
        buffer.append("]");
        return buffer.toString();
    }
}
