/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: RPCMessageInterface.java 595817 2007-11-16 20:49:03Z vgritsenko $
 */

package org.apache.xindice.server.rpc;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.xindice.core.Collection;
import org.apache.xindice.core.DBException;
import org.apache.xindice.core.FaultCodes;
import org.apache.xmlrpc.XmlRpcException;
import org.apache.xmlrpc.XmlRpcHandler;
import org.apache.xmlrpc.XmlRpcRequest;

import org.xmldb.api.base.ErrorCodes;
import org.xmldb.api.base.XMLDBException;

import java.util.Map;

/**
 *
 * @version $Revision: 595817 $, $Date: 2007-11-16 15:49:03 -0500 (Fri, 16 Nov 2007) $
 */
public final class RPCMessageInterface implements XmlRpcHandler {

    private static final Log log = LogFactory.getLog(Collection.class);

    public static final String MESSAGE_PARAM = "message";

    /**
     * Single instance of handler is enough
     */
    private static final XmlRpcHandler INSTANCE = new RPCMessageInterface();


    public static XmlRpcHandler getHandler() {
        return INSTANCE;
    }


    private RPCMessageInterface() {
    }

    public Object execute(XmlRpcRequest xmlRpcRequest) throws XmlRpcException {
        Map message = (Map) xmlRpcRequest.getParameter(0);

        // The method determines what class we load to handle the message.
        String type = (String) message.get(MESSAGE_PARAM);
        try {
            RPCMessage handler = (RPCMessage) Class.forName("org.apache.xindice.server.rpc.messages." + type).newInstance();
            return handler.execute(message);
        } catch (XMLDBException e) {
            if (log.isDebugEnabled()) {
                log.debug("Exception while processing XmlRpc command " + type, e);
            }

            throw new XmlRpcException(e.errorCode * FaultCodes.MAX_CODE + e.vendorErrorCode,
                                      e.getMessage());
        } catch (DBException e) {
            if (log.isDebugEnabled()) {
                log.debug("Exception while processing XmlRpc command " + type, e);
            }

            //noinspection PointlessArithmeticExpression
            throw new XmlRpcException(ErrorCodes.VENDOR_ERROR * FaultCodes.MAX_CODE + e.faultCode,
                                      e.getMessage());
        } catch (Exception e) {
            if (log.isDebugEnabled()) {
                log.debug("Exception while processing XmlRpc command " + type, e);
            }

            //noinspection PointlessArithmeticExpression
            throw new XmlRpcException(ErrorCodes.UNKNOWN_ERROR * FaultCodes.MAX_CODE + FaultCodes.GEN_UNKNOWN,
                                      e.getMessage());
        }
    }
}
