/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: CreateCollection.java 595817 2007-11-16 20:49:03Z vgritsenko $
 */

package org.apache.xindice.server.rpc.messages;

import org.apache.xindice.core.CollectionManager;
import org.apache.xindice.server.rpc.RPCDefaultMessage;
import org.apache.xindice.util.Configuration;
import org.apache.xindice.xml.dom.DOMParser;
import org.apache.xindice.xml.dom.DocumentImpl;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import java.util.HashMap;
import java.util.Map;

/**
 *
 * @version $Revision: 595817 $, $Date: 2007-11-16 15:49:03 -0500 (Fri, 16 Nov 2007) $
 */
public class CreateCollection extends RPCDefaultMessage {

    public Map execute(Map message) throws Exception {

        if (!message.containsKey(COLLECTION)) {
            throw new Exception(MISSING_COLLECTION_PARAM);
        }

        if (!message.containsKey(CONFIGURATION) && !message.containsKey(NAME)) {
            throw new Exception(MISSING_CONFIGURATION_PARAM);
        }

        Document doc;
        // Handle the case where we're getting an entire configuration document.
        if (message.containsKey(CONFIGURATION)) {
            doc = DOMParser.toDocument((String) message.get(CONFIGURATION));
            if (doc == null) {
                throw new Exception("Unable to parse Collection configuration");
            }
        }
        // Otherwise we need to build the configuration from the name and pattern.
        else {
            // FIXME Use default config defined somewhere else
            doc = new DocumentImpl();

            Element colEle = doc.createElement("collection");
            colEle.setAttribute("compressed", "true");
            colEle.setAttribute("name", (String) message.get(NAME));
            doc.appendChild(colEle);

            Element filEle = doc.createElement("filer");
            filEle.setAttribute("class", "org.apache.xindice.core.filer.BTreeFiler");
            colEle.appendChild(filEle);
        }

        CollectionManager colman = getCollection((String) message.get(COLLECTION));

        Configuration config = new Configuration(doc.getDocumentElement(), false);
        colman.createCollection((String) message.get(NAME), config);

        Map result = new HashMap(3);
        result.put(RESULT, message.get(NAME));
        return result;
    }
}
