/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DeploymentTask.java 578602 2007-09-23 20:33:31Z natalia $
 */

package org.apache.xindice.tools;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.apache.xindice.server.Xindice;

/**
 * Handles basic deployment of Xindice services using ant.
 *
 * @author <a href="mailto:kstaken@xmldatabases.org">Kimbro Staken</a>
 * @version $Revision: 578602 $, $Date: 2007-09-23 16:33:31 -0400 (Sun, 23 Sep 2007) $
 */
public class DeploymentTask extends Task {
    private String home = "";
    private XMLTools.Config config = null;

    /**
     * Constructor for creating a new DeploymentTask.
     */
    public DeploymentTask() {
        config = new XMLTools.Config();
    }

    /**
     *  Sets the action name to be performed.
     *
     * @param action The name of the action
     */
    public void setAction(String action) {
        config.setString(XMLTools.ACTION, action);
    }

    /**
     *  Sets collection context.
     *
     * @param context Target collection URL
     */
    public void setCollection(String context) {
        config.setString(XMLTools.COLLECTION, context);
    }

    /**
     *  Sets the Name to use for the document or collection.
     *
     * @param name The new Name value
     */
    public void setName(String name) {
        config.setString(XMLTools.NAME_OF, name);
    }

    /**
     *  Sets the filer to use for the collection.
     *
     * @param filer The new Name value
     */
    public void setFiler(String filer) {
        config.setString(XMLTools.FILER, filer);
    }

    /**
     *  Sets the page size attribute for collection.
     *
     * @param pageSize The new Name value
     */
    public void setPageSize(String pageSize) {
        config.setString(XMLTools.PAGE_SIZE, pageSize);
    }

    /**
     *  Sets the page count attribute for collection.
     *
     * @param pageCount The new Name value
     */
    public void setPageCount(String pageCount) {
        config.setString(XMLTools.PAGE_COUNT, pageCount);
    }

    /**
     *  Sets index pattern.
     *
     * @param pattern The new Name value
     */
    public void setPattern(String pattern) {
        config.setString(XMLTools.PATTERN, pattern);
    }

    /**
     *  Sets index type.
     *
     * @param type The new Name value
     */
    public void setType(String type) {
        config.setString(XMLTools.PATTERN, type);
    }

    /**
     *  Sets the Home attribute of the DeploymentTask object
     *
     * @param  name  The new Home value
     */
    public void setHome(String name) {
        this.home = name;
    }

    /**
     *  Sets the Path attribute of the DeploymentTask object
     *
     * @param  name  The new Path value
     */
    public void setPath(String name) {
        config.setString(XMLTools.FILE_PATH, name);
    }

    /**
     *  Sets the Activity attribute of the DeploymentTask object
     *
     * @param  name  The new Activity value
     * @deprecated 
     */
    public void setActivity(String name) {
        config.setString(XMLTools.ACTION, name);
    }

    /**
     *  Executes the task.
     *
     * @exception  BuildException  Description of Exception
     */
    public void execute() throws BuildException {
        if (this.home.equals("")) {
            throw new BuildException("You must specify the home attribute for deployment");
        }

        // Set the home directory so the XMLAdmin object can find its configuration.
        System.getProperties().put(Xindice.PROP_XINDICE_HOME, home);

        // Run the task.
        try {
            new XMLTools(config).execute();
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("Error executing deployment task", e);
        }
    }

}

