/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: HelpCommand.java 578602 2007-09-23 20:33:31Z natalia $
 */
package org.apache.xindice.tools.command;

import org.apache.xindice.server.Xindice;
import org.apache.xindice.util.StringUtilities;
import org.apache.xindice.tools.XMLTools;

import java.util.List;

/**
 *
 * @author <a href="mailto:byrne@apache.org">Todd Byrne</a>
 * @version $Revision: 578602 $, $Date: 2007-09-23 16:33:31 -0400 (Sun, 23 Sep 2007) $
 */
public class HelpCommand extends Command {

	public boolean execute(XMLTools.Config table) throws Exception {
		List list = table.getActions();

		// This method relies on XML file Commands.xml attribute "helpclass" -
        // used to order output

        // Show the header and general switches
        System.out.println();
        System.out.println("Xindice Command Tools v" + Xindice.Version);
        System.out.println();
        System.out.println("Format: xindice <action> [parameters]");
        System.out.println();
        System.out.println("General purpose switches:");
        System.out.println("    -c|--collection <context>");
        System.out.println("                 Collection context (must always be specified), can be either");
        System.out.println("                 canonical name of the collection or complete xmldb URL");
        System.out.println("    -l|--localdb");
        System.out.println("                 Use a local database rather then going over the network.");
        System.out.println("                 Should be combined with -d to specify the configuration to use");
        System.out.println("    -d|--dbconfig <path>");
        System.out.println("                 Path to the database configuration to use for the local ");
        System.out.println("                 database. Only applies if -l is specified.");
        System.out.println("    -v|--verbose");
        System.out.println("                 Verbose. Outputs additional information and exceptions");
        System.out.println("    -h|--help");
        System.out.println("                 Print help screen for an action");
        System.out.println();
		System.out.println("Actions:");

        String helpClass;  // Holds the helpclass for the current <command> node

        // Show all elements with helpclass=document
		// Loop over the commands, printing test from description attribute
		for (int i = 0; i < list.size(); i++) {
            XMLTools.Action action = (XMLTools.Action) list.get(i);
            helpClass = action.helpclass;

			if (helpClass.equals("document")) {
				System.out.println("    " + StringUtilities.leftJustify(action.switchName, 13) + action.description);
			}
		}

		// Loop over the commands, printing text from description attribute
		for (int i = 0; i < list.size(); i++) {
            XMLTools.Action action = (XMLTools.Action) list.get(i);
            helpClass = action.helpclass;

			if (helpClass.equals("security")) {
                System.out.println("    " + StringUtilities.leftJustify(action.switchName, 13) + action.description);
			}
		}

        System.out.println();
		System.out.println("For more information, please read the Xindice - Tools Reference Guide");
		System.out.println();
		return true;
	}

    public void usage() {
        System.out.println("Format: xindice help");
        System.out.println();
        System.out.println("Describes usage of Xindice Command Tools");
        System.out.println();
    }
}
