/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Shutdown.java 593003 2007-11-08 03:12:23Z natalia $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.client.xmldb.services.DatabaseInstanceManager;
import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;

/**
 * Shutdown.java is designed to let the user shutdown
 * the Database.
 *
 * @version $Revision: 593003 $, $Date: 2007-11-07 22:12:23 -0500 (Wed, 07 Nov 2007) $
 */
public class Shutdown extends Command {

    //public boolean execute(Hashtable table, Database db)
    public boolean execute(XMLTools.Config table) throws Exception {

        if (table.getString(XMLTools.COLLECTION) == null) {
            System.out.println("ERROR : Collection context required ");
            return false;
        }

        Collection col = null;
        try {
            // Collection name can be incorrect, use database name instead
            String context = table.getString(XMLTools.COLLECTION);
            String db = getDbName(context);

            // Get a Collection reference to pass on to individual commands
            String colstring = normalizeCollectionURI(db, table.getBoolean(XMLTools.LOCAL));
            col = DatabaseManager.getCollection(colstring);

            if (col != null) {
                DatabaseInstanceManager man =
                        (DatabaseInstanceManager) col.getService("DatabaseInstanceManager", XMLDBAPIVERSION);

                // Shutdown the server
                man.shutdown();
            }
        } finally {
            if (col != null) {
                col.close();
            }
        }

        return true;
    }

    private String getDbName(String context) {
        int i = context.indexOf("://");
        i = i < 0 ? 0 : i + 3;

        int start = context.indexOf('/', i);
        int end = context.indexOf('/', start + 1);
        if (end == -1) {
            end = context.length();
        }

        return context.substring(0, end);
    }

    public void usage() {
        System.out.println("Format: xindice shutdown  -c <context> [-l [-d <path>]] [-v]");
        System.out.println();
        System.out.println("Shuts down the database. Shutdown command only works with embedded driver");
        System.out.println();
    }
}
