/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: CollectionConfigurationViewer.java 541515 2007-05-25 02:45:06Z vgritsenko $
 */

package org.apache.xindice.webadmin.viewer.components;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.xindice.core.Collection;
import org.apache.xindice.util.ReadOnlyException;
import org.apache.xindice.webadmin.viewer.HtmlCollectionViewer;
import org.apache.xindice.webadmin.viewer.HtmlViewerComponent;
import org.apache.xindice.xml.Xml2HtmlWriter;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Xindice Html Viewer for Collection configuration.
 *
 * @author <a href="mailto:jmetzner@apache.org">Jan Metzner</a>
 * @version $Revision: 541515 $, $Date: 2007-05-24 22:45:06 -0400 (Thu, 24 May 2007) $
 */
public class CollectionConfigurationViewer extends HtmlViewerComponent implements HtmlCollectionViewer {

    private static final Log log = LogFactory.getLog(CollectionConfigurationViewer.class);

    public void execute(HttpServletRequest req, HttpServletResponse res, Collection col)
            throws ServletException, IOException {

        String path = col.getCanonicalName();
        String title = "Collection Configuration for " + path;

        ServletOutputStream output = startViewer(title, path, res);
        printStartTable(title, output);
        printStartSingleTableBox(output);

        try {
            Xml2HtmlWriter.write(col.getConfig().getElement(), output);
            printEndSingleTableBox(output);
            printEndTable(output);
        } catch (ReadOnlyException e) {
            log.error(e);
            output.print("Cannot read configuration: ");
            output.print(e.getMessage());
        }

        printEndSingleTableBox(output);
        printEndTable(output);
        finishViewer(output);
    }

    protected String getName() {
        return "config";
    }

}
