/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Get.java 551444 2007-06-28 04:39:52Z vgritsenko $
 */

package org.apache.xindice.webadmin.webdav.components;

import java.io.IOException;
import java.io.OutputStream;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.DBException;
import org.apache.xindice.core.data.Entry;
import org.apache.xindice.webadmin.util.MimeTable;
import org.apache.xindice.webadmin.webdav.DAVRequest;
import org.apache.xindice.webadmin.webdav.DAVResponse;
import org.apache.xindice.webadmin.Location;
import org.apache.xindice.xml.TextWriter;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.w3c.dom.Document;

/**
 * This class implements the Get HTTP command for WebDAV operations on
 * Xindice.
 *
 * @author <a href="mailto:jmetzner@apache.org">Jan Metzner</a>
 * @author <a href="mailto:gianugo@apache.org">Gianugo Rabellino</a>
 * @version $Revision: 551444 $, $Date: 2007-06-28 00:39:52 -0400 (Thu, 28 Jun 2007) $
 */
public class Get implements DAVComponent {

    private static final Log log = LogFactory.getLog(Get.class);

    public void execute(DAVRequest req, DAVResponse res, Location target) throws ServletException, IOException {
        if (target.getName() == null) {
            res.setStatus(HttpServletResponse.SC_NOT_IMPLEMENTED);

        } else {
            Collection col = target.getCollection();
            String name = target.getName();

            try {
                Entry resource = col.getEntry(name);

                if (resource != null) {

                    byte[] resultBytes;
                    if (resource.getEntryType() == Entry.DOCUMENT) {
                        resultBytes = TextWriter.toString((Document) resource.getValue()).getBytes();
                        res.setContentType(MimeTable.XML_MIME_TYPE);
                    } else {
                        resultBytes = (byte[]) resource.getValue();
                        res.setContentType(MimeTable.getMimeType(name));
                    }

                    if (resource.getModificationTime() != 0) {
                        res.addDateHeader("Last-Modified", resource.getModificationTime());
                    }
                    res.setContentLength(resultBytes.length);

                    OutputStream output = res.getOutputStream();
                    output.write(resultBytes);
                    output.flush();
                } else {
                    res.setStatus(HttpServletResponse.SC_NOT_FOUND);
                }
            } catch (DBException e) {
                log.error("Could not get resource " + name + " from collection " + col.getCanonicalName(), e);
                throw new ServletException(e);
            }

        }

    }
}
