/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.xindice.webadmin.webdav.components.props;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.data.Entry;
import org.apache.xindice.webadmin.PartialResponse;

/**
 * ResourceType creates a response node that identifies resource type
 * (collection or collection entry).<br/>
 * <br/>
 * When invoked for collections, it will generate
 * <pre>
 * &lt;resourcetype&gt;
 *     &lt;collection/&gt;
 * &lt;/resourcetype&gt;
 * </pre>
 *
 * For collection entries, it will be
 * <pre>
 * &lt;resourcetype/&gt;
 * </pre>
 *
 * @version $Revision: 541515 $, $Date: 2007-05-24 22:45:06 -0400 (Thu, 24 May 2007) $
 */
public class ResourceType implements DAVProperty {
    private static final String RESOURCE_TYPE = "resourcetype";
    private static final String COLLECTION = "collection";

    public String getName() {
        return RESOURCE_TYPE;
    }

    public PartialResponse.Content getRootProperty() {
        PartialResponse.Content node = new PartialResponse.Content(RESOURCE_TYPE);
        node.addChild(COLLECTION);

        return node;
    }

    public PartialResponse.Content getProperty(Collection col) {
        PartialResponse.Content node = new PartialResponse.Content(RESOURCE_TYPE);
        node.addChild(COLLECTION);

        return node;
    }

    public PartialResponse.Content getProperty(Entry entry) {
        return new PartialResponse.Content(RESOURCE_TYPE);
    }

}
