/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DBDocument.java 571948 2007-09-02 10:51:37Z vgritsenko $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.Document;

/**
 * DBDocument represents a Xindice Collection-originating Document.
 *
 * @version $Revision: 571948 $, $Date: 2007-09-02 06:51:37 -0400 (Sun, 02 Sep 2007) $
 */
public interface DBDocument extends DBNode, Document {

    /**
     * Cache control processing instruction
     */
    String CACHE_CONTROL = "xindice-cache";

    /**
     * 'cache' value of the cache control processing instruction
     */
    String CACHE = "cache";

    /**
     * 'no-cache' value of the cache control processing instruction
     */
    String NOCACHE = "no-cache";

    /**
     * getCaching returns whether or not this Document should be cached
     * by some sort of caching mechanism.
     *
     * @return Whether or not the Document can be cached
     */
    boolean isCaching();

    /**
     * setCaching sets whether or not this Document should be cached
     * by some sort of caching mechanism.
     *
     * @param caching Whether or not the Document can be cached
     */
    void setCaching(boolean caching);
}
