/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: EntityImpl.java 571948 2007-09-02 10:51:37Z vgritsenko $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.Entity;
import org.w3c.dom.Node;

/**
 * EntityImpl
 *
 * @version $Revision: 571948 $, $Date: 2007-09-02 06:51:37 -0400 (Sun, 02 Sep 2007) $
 */
public final class EntityImpl extends NodeImpl implements Entity {

    private String encoding;
    private String inputEncoding;
    private String version;


    public EntityImpl() {
    }

    public EntityImpl(NodeImpl parent, byte[] data, int pos, int len) {
        super(parent, data, pos, len);
    }

    public EntityImpl(NodeImpl parent, boolean dirty) {
        super(parent, dirty);
    }

    public short getNodeType() {
        return Node.ENTITY_NODE;
    }

    /**
     * The public identifier associated with the entity, if specified. If the
     * public identifier was not specified, this is <code>null</code>.
     */
    public String getPublicId() {
        return null;
    }

    /**
     * The system identifier associated with the entity, if specified. If the
     * system identifier was not specified, this is <code>null</code>.
     */
    public String getSystemId() {
        return null;
    }

    /**
     * For unparsed entities, the name of the notation for the entity. For
     * parsed entities, this is <code>null</code>.
     */
    public String getNotationName() {
        return null;
    }

    public String getInputEncoding() {
        checkLoaded();
        return inputEncoding;
    }

    public String getXmlEncoding() {
        checkLoaded();
        return encoding;
    }

    // DOM Level 3 Stuff
    public String getXmlVersion() {
        checkLoaded();
        return version;
    }

    // Setters
    public void setEncoding(String encoding) {
        checkReadOnly();
        checkLoaded();
        this.encoding = encoding;
    }

    public void setInputEncoding(String inputEncoding) {
        checkReadOnly();
        checkLoaded();
        this.inputEncoding = inputEncoding;
    }

    public void setXmlVersion(String version) {
        checkReadOnly();
        checkLoaded();
        this.version = version;
    }
}
