/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: TextImpl.java 571948 2007-09-02 10:51:37Z vgritsenko $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.DOMException;
import org.w3c.dom.Node;
import org.w3c.dom.Text;

/**
 * TextImpl
 *
 * @version $Revision: 571948 $, $Date: 2007-09-02 06:51:37 -0400 (Sun, 02 Sep 2007) $
 */
public class TextImpl extends CharacterDataImpl
                      implements Text {

    public TextImpl() {
    }

    public TextImpl(NodeImpl parent, byte[] data, int pos, int len) {
        super(parent, data, pos, len);
    }

    public TextImpl(NodeImpl parent, boolean dirty) {
        super(parent, dirty);
    }

    public TextImpl(NodeImpl parent, String nodeValue) {
        super(parent, nodeValue);
    }

    public short getNodeType() {
        return Node.TEXT_NODE;
    }

    public String getNodeName() {
        return "#text";
    }

    /**
     * Breaks this <code>Text</code> node into two Text nodes at the specified
     * offset, keeping both in the tree as siblings. This node then only
     * contains all the content up to the <code>offset</code> point. And a new
     * <code>Text</code> node, which is inserted as the next sibling of  this
     * node, contains all the content at and after the <code>offset</code>
     * point.
     * @param offset The offset at which to split, starting from 0.
     * @return The new <code>Text</code> node.
     * @exception DOMException
     *   INDEX_SIZE_ERR: Raised if the specified offset is negative or greater
     *   than the number of characters in <code>data</code>.
     *   <br>NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
     */
    public final Text splitText(int offset) throws DOMException {
        String value = getNodeValue();
        checkReadOnly();
        try {
            String newValue = value.substring(0, offset);
            String oldValue = value.substring(offset + 1);
            Text text = getOwnerDocument().createTextNode(newValue);
            setNodeValue(oldValue);
            getParentNode().insertBefore(text, this);
            setDirty();
            return text;
        } catch (Exception e) {
            throw EX_INDEX_SIZE;
        }
    }

    /**
     * @since DOM Level 3
     */
    public boolean isElementContentWhitespace() {
        return false;
    }

    /**
     * @since DOM Level 3
     */
    public String getWholeText() {
        throw new DOMException(DOMException.NOT_SUPPORTED_ERR, "Operation is not supported");
    }

    /**
     * @since DOM Level 3
     */
    public Text replaceWholeText(String content) throws DOMException {
        throw new DOMException(DOMException.NOT_SUPPORTED_ERR, "Operation is not supported");
    }
}
