/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: XmlDbClientSetup.java 511423 2007-02-25 03:21:05Z vgritsenko $
 */

package org.apache.xindice.integration.client;

import junit.framework.Test;
import junit.framework.TestSuite;
import junitx.extensions.TestSetup;

/**
 * @version $Revision: 511423 $, $Date: 2007-02-24 22:21:05 -0500 (Sat, 24 Feb 2007) $
 * @author Vladimir R. Bossicard <vladimir@apache.org>
 */
public class XmlDbClientSetup extends TestSetup {

    public static final String INSTANCE_NAME = "db";
    public static final String TEST_COLLECTION_NAME = "testing";

    private XmlDbClient client;

    public XmlDbClientSetup(Test test,
                            XmlDbClient client) {
        super(test);
        this.client = client;
    }

    public void setUp() throws Exception {

        this.client.createCollection(INSTANCE_NAME, TEST_COLLECTION_NAME);

        // now we set all tests with the client
        // we have an TestSuite of TestSuite of AbstractXmlDbClientTest :-)
        TestSuite suite = (TestSuite) fTest;
        for (int ii = 0; ii < suite.testCount(); ii++) {
            TestSuite subSuite = (TestSuite) suite.testAt(ii);
            for (int jj = 0; jj < subSuite.testCount(); jj++) {
                Object obj = subSuite.testAt(jj);
                if (obj instanceof AbstractXmlDbClientTest) {
                    AbstractXmlDbClientTest test = (AbstractXmlDbClientTest) obj;
                    test.setXmlDbClient(this.client);
                }
            }
        }
    }

    public void tearDown() throws Exception {
        this.client.dropCollection(INSTANCE_NAME, TEST_COLLECTION_NAME);
    }
}
