/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: IndexTest.java 566416 2007-08-15 23:58:48Z vgritsenko $
 */

package org.apache.xindice.integration.client.basic;

import org.apache.xindice.integration.client.AbstractXmlDbClientTest;

import org.w3c.dom.Document;
import org.xmldb.api.base.XMLDBException;

import java.util.Arrays;
import java.util.Vector;

/**
 * @version $Revision: 566416 $, $Date: 2007-08-15 19:58:48 -0400 (Wed, 15 Aug 2007) $
 * @author Vladimir R. Bossicard <vladimir@apache.org>
 */
public class IndexTest extends AbstractXmlDbClientTest {

    public void testCreateIndexer() throws Exception {
        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("goodindexer"));
        this.client.dropIndexer(TEST_COLLECTION_PATH, "goodindexer");
    }

    private String getIndexDef(String name) {
        return "<?xml version='1.0'?>" +
               "<index class='org.apache.xindice.core.indexer.ValueIndexer' name='" + name + "' pattern='pattern'/>";
    }

    public void testCreateDuplicateIndexer() throws Exception {
        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("duplicate"));
        try {
            this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("duplicate"));
            fail();
        } catch (XMLDBException e) {
            // assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
        } finally {
            this.client.dropIndexer(TEST_COLLECTION_PATH, "duplicate");
        }
    }

    public void testCreateIndexerNullDefinition() throws Exception {
        try {
            this.client.createIndexer(TEST_COLLECTION_PATH, (Document) null);
            fail();
        } catch (XMLDBException e) {
            // assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
        }
    }

    public void testCreateIndexerEmptyName() throws Exception {
        try {
            this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef(""));
            fail();
        } catch (XMLDBException e) {
            // assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
        }
    }

    public void testCreateIndexerInvalidClass() throws Exception {
        try {
            this.client.createIndexer(TEST_COLLECTION_PATH,
                    "<?xml version='1.0'?>" +
                    "<index class='org.apache.xindice.core.indexer.BlahIndexer' name='blah' pattern='blah'/>");
            fail();
        } catch (XMLDBException e) {
            // assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
        }
    }

    public void testDropIndexerTwice() throws Exception {
        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("droptwice"));
        this.client.dropIndexer(TEST_COLLECTION_PATH, "droptwice");

        // drop the newly created index
        try {
            this.client.dropIndexer(TEST_COLLECTION_PATH, "droptwice");
            fail();
        } catch (XMLDBException e) {
            //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
        }
    }

    public void testDropIndexerInvalidName() throws Exception {
        try {
            this.client.dropIndexer(TEST_COLLECTION_PATH, "");
            fail();
        } catch (XMLDBException e) {
            //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
        }
    }

    public void testDropIndexerNullName() throws Exception {
        try {
            this.client.dropIndexer(TEST_COLLECTION_PATH, null);
            fail();
        } catch (XMLDBException e) {
            //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
        }
    }

    public void testListIndexers() throws Exception {
        String[] indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(0, indexes.length);

        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("index1"));
        indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(1, indexes.length);
        assertEquals("index1", indexes[0]);

        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("index2"));
        indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(2, indexes.length);
        Vector lst = new Vector(Arrays.asList(indexes));
        assertTrue(lst.contains("index1"));
        assertTrue(lst.contains("index2"));

        this.client.dropIndexer(TEST_COLLECTION_PATH, "index1");
        indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(1, indexes.length);
        assertEquals("index2", indexes[0]);

        this.client.dropIndexer(TEST_COLLECTION_PATH, "index2");
        indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(0, indexes.length);
    }
}
