/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: NodeListTest.java 518749 2007-03-15 20:38:08Z vgritsenko $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

/**
 * Tests NodeListImpl class
 *
 * @version $Revision: 518749 $, $Date: 2007-03-15 16:38:08 -0400 (Thu, 15 Mar 2007) $
 */
public class NodeListTest extends DOMTestCase {

    public String getXml() {
        return
            "<a>" +
              "<b/>" +
              "<c>" +
                "<d/>" +
              "</c>" +
              "<i/>" +
            "</a>";
    }

    public void testOutOfBounds() throws Exception {
        NodeList list = root.getChildNodes();
        assertEquals(3, list.getLength());
        assertNull(list.item(-1));
        assertNull(list.item(3));
    }

    public void testElementsByTagName() throws Exception {
        Element element = (Element) root.getFirstChild().getNextSibling();
        assertEquals("c", element.getTagName());

        NodeList list = element.getElementsByTagName("i");
        assertEquals(0, list.getLength());

        list = element.getElementsByTagName("d");
        assertEquals(1, list.getLength());
        assertEquals("d", ((Element) list.item(0)).getTagName());
    }
}
